History
=======


1.0.6 (2017-07-10)
------------------

* Simplified the mara.protocols pacakge.

1.0.2 - 1.0.5 (2017-07-10)
--------------------------

* Added maranet.__version__
* Renamed maranet.mara to maranet.protocols
* CLI entrypoints working
    - maranet client
    - maranet direct_poll

1.0.1 (2017-07-09)
------------------

* Move code to cookiecutter python pacakge.

1.0 (2017-07-09)
------------------

* First release on PyPI. The sourcecode is extracted from https://github.com/d3f0/txscada and placed in an independet package.


<1.0 (2009-08-06-)
------------------

* Mara is part of txscada project, involved in a Traffic Light system based on PyQt4 and MySQL.
* Mara is extended to a 16 bit version to be used on a Power Substation Monitoring Software.

.. image:: docs/img/mara_in_use.jpg
    :width: 50%
